import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleLinear,scaleBand,scaleLog, max, format, extent,ascending } from 'd3';
import ReactDropdown from 'react-dropdown';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = 960;
const menuHeight = 80;
const height = 500 - menuHeight;
const margin = { top: 0, right: 30, bottom:20, left: 120 };
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 45;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  const siFormat = format('.2s');
  const xAxisTickFormat = tickValue => siFormat(tickValue).replace('G', 'B');

   const filteredData = data.filter(d => d.Dateofmonth == 31);

 const yScale = scaleBand()
	 .domain(filteredData.map(d => d.location))
   .range([ innerHeight,0])
   .paddingInner(0.15)

 
  const xScale = scaleLinear()
   .domain([0,1900000])
  .range([0, innerWidth]);
 
  
	const sortedFilteredData=filteredData.slice().sort((a, b) => d3.ascending(a.total_cases, b.location))
  const yValue = d => d.location;
  const xValue = d => d.total_cases;

 return (
    <>
      <svg width={width} height={height}>
        <g transform={`translate(${margin.left},${margin.top})`}>
          <AxisLeft yScale={yScale} />
          <AxisBottom xScale={xScale} innerHeight={innerHeight} tickFormat={xAxisTickFormat} />
          <Marks
          data={sortedFilteredData}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
        />
   			</g>
      </svg>
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
